aboutsummaryrefslogtreecommitdiffstats
path: root/activestorage/app/models/active_storage/variation.rb
diff options
context:
space:
mode:
Diffstat (limited to 'activestorage/app/models/active_storage/variation.rb')
-rw-r--r--activestorage/app/models/active_storage/variation.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/activestorage/app/models/active_storage/variation.rb b/activestorage/app/models/active_storage/variation.rb
index 3bdbc5bacb..259bbc743e 100644
--- a/activestorage/app/models/active_storage/variation.rb
+++ b/activestorage/app/models/active_storage/variation.rb
@@ -103,10 +103,10 @@ class ActiveStorage::Variation
image.tempfile.tap(&:open)
end
# Returns the ImageProcessing processor class specified by `ActiveStorage.processor`.
def processor
require "image_processing"
- ImageProcessing.const_get(ActiveStorage.processor.to_s.camelize) if ActiveStorage.processor
+ ImageProcessing.const_get(ActiveStorage.variant_processor.to_s.camelize) if ActiveStorage.variant_processor
rescue LoadError
ActiveSupport::Deprecation.warn("Using mini_magick gem directly is deprecated and will be removed in Rails 6.1. Please add `gem 'image_processing', '~> 1.2'` to your Gemfile.")
end
@@ -103,10 +103,10 @@ class ActiveStorage::Variation
image.tempfile.tap(&:open)
end
- # Returns the ImageProcessing processor class specified by `ActiveStorage.processor`.
+ # Returns the ImageProcessing processor class specified by `ActiveStorage.variant_processor`.
def processor
require "image_processing"